doapfiend.model.Project

Package doapfiend :: Module model :: Class Project |
[hide private]
[frames] | no frames]

# Class Project

source code

          object --+
                   |
    utils.rdfSubject --+
                       |
                      Project

DOAP Project Class

Instance Methods | [hide private]
Inherited from `utils.rdfSubject`: `__delitem__`, `__getitem__`, `__init__`, `__repr__`, `md5_term_hash`, `n3` Inherited from `utils.rdfSubject` (private): `_ppo`, `_remove`, `_rename`, `_set_with_dict` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `utils.rdfSubject`: `ClassInstances`, `GetRandom`, `filter_by`, `get_by`, `query` Inherited from `utils.rdfSubject` (private): `_getdescriptor`

Class Variables | [hide private]
| rdf_type = `rdflib.URIRef('http://usefulinc.com/ns/doap#Project')`
| category = `rdfMultiple(DOAP.category)`
| created = `rdfSingle(DOAP.created)`
| shortname = `rdfSingle(DOAP.shortname)`
| description = `rdfMultiple(DOAP.description)`
| bug_database = `rdfSingle(DOAP ['bug-database'])`
| developer = `rdfMultiple(DOAP.developer, range_type= FOAF.Person)`
| documenter = `rdfMultiple(DOAP.documenter, range_type= FOAF.Per`...``
| download_mirror = `rdfMultiple(DOAP ['downoad-mirror'])`
| download_page = `rdfSingle(DOAP ['download-page'])`
| helper = `rdfMultiple(DOAP.helper, range_type= FOAF.Person)`
| homepage = `rdfSingle(DOAP.homepage)`
| license = `rdfMultiple(DOAP ['license'])`
| maintainer = `rdfMultiple(DOAP.maintainer, range_type= FOAF.Per`...``
| module = `rdfSingle(DOAP.module)`
| name = `rdfSingle(DOAP.name)`
| old_homepage = `rdfMultiple(DOAP ['old-homepage'])`
| programming_language = `rdfMultiple(DOAP ['programming-language'])`
| releases = `rdfMultiple(DOAP.release, range_type= DOAP.Version)`
| svn_repository = `rdfSingle(DOAP.repository, 'svn_repository', `...``
| cvs_repository = `rdfSingle(DOAP.repository, 'cvs_repository', `...``
| oper_sys = `rdfMultiple(DOAP ['os'])`
| screenshots = `rdfMultiple(DOAP.screenshots)`
| shortdesc = `rdfMultiple(DOAP.shortdesc)`
| tester = `rdfMultiple(DOAP.tester, range_type= FOAF.Person)`
| translator = `rdfMultiple(DOAP.translator, range_type= FOAF.Per`...``
| wiki = `rdfMultiple(DOAP.wiki)`
Inherited from `utils.rdfSubject`: `db`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### documenter Value:
      rdfMultiple(DOAP.documenter, range_type= FOAF.Person)

  ### maintainer Value:
      rdfMultiple(DOAP.maintainer, range_type= FOAF.Person)

  ### svn_repository Value:
      rdfSingle(DOAP.repository, 'svn_repository', range_type= DOAP.SVNRepos
      itory)

  ### cvs_repository Value:
      rdfSingle(DOAP.repository, 'cvs_repository', range_type= DOAP.CVSRepos
      itory)

  ### translator Value:
      rdfMultiple(DOAP.translator, range_type= FOAF.Person)